pub struct NativeSingleThreadDriver { /* private fields */ }Expand description
Native cooperative guest runtime backed by the canonical protocol machine.
Implementations
Sourceimpl NativeSingleThreadDriver
impl NativeSingleThreadDriver
Sourcepub fn new(config: ProtocolMachineConfig) -> Self
pub fn new(config: ProtocolMachineConfig) -> Self
Create a new guest runtime from protocol-machine config.
Sourcepub fn with_vm(machine: ProtocolMachine) -> Self
pub fn with_vm(machine: ProtocolMachine) -> Self
Wrap an existing protocol-machine instance inside this guest runtime.
Sourcepub fn machine(&self) -> &ProtocolMachine
pub fn machine(&self) -> &ProtocolMachine
Access the inner protocol machine.
Sourcepub fn load_choreography_owned(
&mut self,
image: &CodeImage,
owner_id: impl Into<String>,
) -> Result<OwnedSession, ProtocolMachineError>
pub fn load_choreography_owned( &mut self, image: &CodeImage, owner_id: impl Into<String>, ) -> Result<OwnedSession, ProtocolMachineError>
Preferred choreography open path that returns an ownership-bearing handle.
Errors
Returns a ProtocolMachineError if the choreography cannot be loaded or claimed.
Sourcepub fn step_round(
&mut self,
handler: &dyn EffectHandler,
n: usize,
) -> Result<StepResult, ProtocolMachineError>
pub fn step_round( &mut self, handler: &dyn EffectHandler, n: usize, ) -> Result<StepResult, ProtocolMachineError>
Execute one scheduler round via the protocol-machine kernel.
Errors
Returns a ProtocolMachineError if a coroutine faults.
Sourcepub fn run(
&mut self,
handler: &dyn EffectHandler,
max_rounds: usize,
n: usize,
) -> Result<RunStatus, ProtocolMachineError>
pub fn run( &mut self, handler: &dyn EffectHandler, max_rounds: usize, n: usize, ) -> Result<RunStatus, ProtocolMachineError>
Run up to max_rounds with concurrency n via the protocol-machine kernel.
Errors
Returns a ProtocolMachineError if a coroutine faults.