pub struct WalSyncRequest {
pub operation_id: String,
pub downstream_coroutine_id: String,
pub gate_level: AgreementLevel,
pub agreement_state: Option<AgreementState>,
pub agreement_evidence: Vec<AgreementEvidence>,
pub tick: u64,
}Expand description
Typed request payload for the internal wal_sync effect.
Fields
operation_id: StringOperation whose durable state is being synchronized.
downstream_coroutine_id: StringCoroutine released by the visibility gate on success.
gate_level: AgreementLevelRequired agreement level for the gated step.
agreement_state: Option<AgreementState>Current agreement state snapshot for the operation when available.
agreement_evidence: Vec<AgreementEvidence>Agreement evidence attached to the operation when available.
tick: u64Tick at which the gate is attempting to cross.