EffectReentrancyPolicy

Enum EffectReentrancyPolicy 

pub enum EffectReentrancyPolicy {
    Allow,
    RejectSameOperation,
    RejectSameFragment,
}
Reentrancy policy for one effect operation.

Variants



Allow

Reentrancy is permitted.



RejectSameOperation

Reject a second live request for the same operation instance.



RejectSameFragment

Reject a second live request for the same session/fragment scope.

Implementations

Source

impl EffectReentrancyPolicy

pub fn admits( self, active: &EffectResponsibilityDomain, incoming: &EffectResponsibilityDomain, ) -> bool

Whether one incoming request is admitted relative to one active request.