pub enum FlowPredicate {
TargetRolePrefix(String),
FactContains(String),
EndpointRoleMatchesTarget,
All(Vec<FlowPredicate>),
Any(Vec<FlowPredicate>),
}Expand description
Serializable flow-policy predicate over known fact + destination.
Variants
TargetRolePrefix(String)
Allow when destination role starts with prefix.
FactContains(String)
Allow when fact contains substring.
EndpointRoleMatchesTarget
Allow when the fact endpoint role equals destination role.
All(Vec<FlowPredicate>)
Conjunction.
Any(Vec<FlowPredicate>)
Disjunction.
Implementations
Sourceimpl FlowPredicate
impl FlowPredicate
Sourcepub fn eval(&self, knowledge: &KnowledgeFact, target_role: &str) -> bool
pub fn eval(&self, knowledge: &KnowledgeFact, target_role: &str) -> bool
Evaluate this serialized predicate against one fact and target role.