pub struct EnvelopeDiffArtifactV1 {
pub schema_version: String,
pub envelope_diff: EnvelopeDiff,
pub baseline_fragment_hash: String,
pub candidate_fragment_hash: String,
pub envelope_diff_hash: String,
}Expand description
Emitted envelope artifact carrying the diff and stable hashes.
Fields
schema_version: StringSchema version for this artifact payload.
envelope_diff: EnvelopeDiffEnvelope differential payload.
baseline_fragment_hash: StringStable hash of the baseline canonical replay fragment.
candidate_fragment_hash: StringStable hash of the candidate canonical replay fragment.
envelope_diff_hash: StringStable hash of the envelope differential payload.
Implementations
Sourceimpl EnvelopeDiffArtifactV1
impl EnvelopeDiffArtifactV1
Sourcepub fn from_replay_fragments(
baseline_engine: impl Into<String>,
candidate_engine: impl Into<String>,
baseline: &CanonicalReplayFragmentV1,
candidate: &CanonicalReplayFragmentV1,
baseline_max_wave_width: usize,
candidate_max_wave_width: usize,
declared_upper_bound: usize,
effect_determinism_tier: EffectDeterminismTier,
) -> Self
pub fn from_replay_fragments( baseline_engine: impl Into<String>, candidate_engine: impl Into<String>, baseline: &CanonicalReplayFragmentV1, candidate: &CanonicalReplayFragmentV1, baseline_max_wave_width: usize, candidate_max_wave_width: usize, declared_upper_bound: usize, effect_determinism_tier: EffectDeterminismTier, ) -> Self
Build an artifact from replay fragments and computed envelope dimensions.