FaultClass

Enum FaultClass 

pub enum FaultClass {
Show 16 variants Type, Label, Channel, Verification, Invoke, Acquire, Transfer, Speculation, Close, Flow, Progress, OutputCondition, Register, ProgramCounter, Buffer, Credits,
}
Stable fault taxonomy used by snapshot tests and cross-target diagnostics.

Variants



Type

Session-type or value-shape mismatch.



Label

Unknown branch/choice label.



Channel

Channel ownership/lifecycle violation.



Verification

Signature/proof verification failure.



Invoke

Host effect invocation failure.



Acquire

Guard/evidence acquisition failure.



Transfer

Endpoint transfer/delegation failure.



Speculation

Speculation/fork-join failure.



Close

Session close lifecycle failure.



Flow

Information-flow policy violation.



Progress

Progress-token discipline failure.



OutputCondition

Output-condition gating rejection.



Register

Register-addressing failure.



ProgramCounter

Program-counter addressing failure.



Buffer

Buffer saturation/backpressure failure.



Credits

Deterministic credit budget exhaustion.