TransitionRefinementSummary

Struct TransitionRefinementSummary 

pub struct TransitionRefinementSummary {
    pub selected_coro: Option<u64>,
    pub selected_pc: Option<u64>,
    pub selected_type: Option<Value>,
    pub exec_status: Option<String>,
    pub session_type_counts: BTreeMap<u64, u64>,
    pub buffered_message_counts: BTreeMap<u64, u64>,
    pub ready_queue: Vec<u64>,
    pub blocked: BTreeMap<u64, String>,
}
Concrete summary of the most recent scheduler-dispatched transition.

Fields

selected_coro: Option<u64>

Coroutine selected for the most recent step, when available.

selected_pc: Option<u64>

Program counter for the selected coroutine after the most recent step.

selected_type: Option<Value>

Lean-compatible local-type snapshot for the selected coroutine endpoint.

exec_status: Option<String>

Execution status tag for the most recent step, when available.

session_type_counts: BTreeMap<u64, u64>

Per-session local-type counts after the most recent step.

buffered_message_counts: BTreeMap<u64, u64>

Per-session buffered-message counts after the most recent step.

ready_queue: Vec<u64>

Scheduler ready queue after the most recent step.

blocked: BTreeMap<u64, String>

Blocked coroutine tags after the most recent step.