pub struct OperationInstance {
pub operation_id: String,
pub session: Option<SessionId>,
pub owner_id: Option<FragmentOwnerId>,
pub kind: String,
pub phase: OperationPhase,
pub handler_identity: Option<String>,
pub effect_ids: Vec<u64>,
pub dependent_operation_ids: Vec<String>,
pub terminal_publication: Option<String>,
pub budget_ticks: Option<u64>,
pub requires_proof: bool,
}Expand description
First-class view of one operation instance.
Fields
operation_id: Stringsession: Option<SessionId>owner_id: Option<FragmentOwnerId>kind: Stringphase: OperationPhasehandler_identity: Option<String>effect_ids: Vec<u64>dependent_operation_ids: Vec<String>terminal_publication: Option<String>budget_ticks: Option<u64>requires_proof: boolImplementations
Sourceimpl OperationInstance
impl OperationInstance
Sourcepub fn is_parity_critical(&self) -> bool
pub fn is_parity_critical(&self) -> bool
Whether the operation is parity-critical.
Sourcepub fn requires_explicit_finalization(&self) -> bool
pub fn requires_explicit_finalization(&self) -> bool
Whether the operation must traverse the explicit canonical finalization path.
Sourcepub fn commitment_aligned_with_agreement_state(
&self,
state: &AgreementState,
) -> bool
pub fn commitment_aligned_with_agreement_state( &self, state: &AgreementState, ) -> bool
Whether commitment state and agreement state align on terminal truth.