pub struct EffectResponsibilityDomain {
pub footprint_key: String,
pub operation_id: Option<String>,
pub fragment_id: Option<String>,
pub owner_id: Option<String>,
}Expand description
Responsibility domain for reentrancy and footprint checks.
Fields
footprint_key: StringCanonical semantic footprint key.
operation_id: Option<String>Optional operation instance id.
fragment_id: Option<String>Optional fragment id.
owner_id: Option<String>Optional owner id.
Implementations
Sourceimpl EffectResponsibilityDomain
impl EffectResponsibilityDomain
Sourcepub fn same_semantic_footprint(&self, other: &Self) -> bool
pub fn same_semantic_footprint(&self, other: &Self) -> bool
Whether the two domains describe the same semantic footprint.
Sourcepub fn same_operation(&self, other: &Self) -> bool
pub fn same_operation(&self, other: &Self) -> bool
Whether the two domains refer to the same operation.
Sourcepub fn same_fragment(&self, other: &Self) -> bool
pub fn same_fragment(&self, other: &Self) -> bool
Whether the two domains refer to the same fragment.