pub struct ResourceState { /* private fields */ }Expand description
Lean-aligned resource state with commitments and nullifiers.
Implementations
Sourceimpl ResourceState
impl ResourceState
Sourcepub fn commit(&mut self, value: &Value) -> Commitment
pub fn commit(&mut self, value: &Value) -> Commitment
Record a commitment for a value and return the commitment digest.
Sourcepub fn consume(&mut self, value: &Value) -> Result<Nullifier, String>
pub fn consume(&mut self, value: &Value) -> Result<Nullifier, String>
Consume a value by inserting its nullifier.
Errors
Returns an error when the value has already been consumed.
Sourcepub fn verify_uncommitted(&self, value: &Value) -> bool
pub fn verify_uncommitted(&self, value: &Value) -> bool
Check whether a value has not yet been consumed.