pub enum EffectReentrancyPolicy {
Allow,
RejectSameOperation,
RejectSameFragment,
}Expand description
Reentrancy policy for one effect operation.
Variants
Allow
Reentrancy is permitted.
RejectSameOperation
Reject a second live request for the same operation instance.
RejectSameFragment
Reject a second live request for the same session/fragment scope.
Implementations
Sourceimpl EffectReentrancyPolicy
impl EffectReentrancyPolicy
Sourcepub fn admits(
self,
active: &EffectResponsibilityDomain,
incoming: &EffectResponsibilityDomain,
) -> bool
pub fn admits( self, active: &EffectResponsibilityDomain, incoming: &EffectResponsibilityDomain, ) -> bool
Whether one incoming request is admitted relative to one active request.